=======
Credits
=======

Development Lead
----------------

* Guilherme Castelao <guilherme@castelao.net>

Contributors
------------

* Luiz Irber <luiz.irber@gmail.com>; Plenty suggestions, discussions and contributions.
* David Goldsmith <eulergaussriemann@gmail.com>; Edited overview.rst.
* Rohan Dandavati; Provided the CTD-bottle example file: MI18MHDR.btl
* Suki Wong; Reported bug #42 on cnv2nc.
* Paul Focke; Position base splitting #45.
* Amber York; Reported bug #41 on reading bottle files.
* Achim Randelhoff; minor improvements in documentation
* Uday Bhaskar; Provided SK287_CTD05.cnv, data columns with headers.
                Reported bad path on seabird_dir() for windows machines.
* Mathew Biddle; Reported bug #53 on skipping first line if without header.
* @atorr018; Reported bug #51 on failing to parse due to a empty lines.
* @shaunwbell; Fixed bug #55 on typos in cnv rules reference names.
* @aer205; Bug #56, provided sample with extra descriptors after file_type.
* @botheredbybees; Fixed bug #57, typo on strftime format for cnv2nc
* @callumrollo; PR #61, adding datetime when exporting to pd.DataFrame
